@@ -1,6 +1,6 @@
 #'  Upload file to an article 
 #' 
-#' @details Article must be a draft, i.e. created by \code{\link{fs_create}} and not yet made public or private. Only articles of type "fileset" can have multiple files uploaded.  
+#' @details Articles may be draft, private or public but all uploads are saved as draft changes - the canonical public version of the deposit is not updated. To update the public version of the repository, use \code{\link{fs_make_public}}. Only articles of type "fileset" can have multiple files uploaded.  
 #' @author Carl Boettiger \email{cboettig@@gmail.com}
 #' @param article_id an article id number or a character string (or list) of numbers
 #' @param file path to file to upload, or character string (or list) of files (paths)
@@ -58,6 +58,6 @@ fs_upload_one  <- function(article_id, file, session = fs_get_auth()) {
   body <- list(filedata = upload_file(file))
   config <- c(config(token = session), add_headers("Content-Type" = "multipart/form-data"))
   out <- PUT(request, config = config, body = body)
-  fs_tag_as_rfigshare(article_id)
+  fs_tag_as_rfigshare(article_id, session = session)
   out
 }
